@@ -3,7 +3,7 @@
  *
  * GKrellM LongRun Plugin
  * Initial work by: (c) 2001 Nozomi Sato (nozomi@palette.plala.or.jp)
- * Copyright (c) 2001-2003 Masaharu FUJITA
+ * Copyright (c) 2001-2004 Masaharu FUJITA
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,27 +25,28 @@
  *	     http://fjts.org/~m/Soft/GKrelLongRun/index_e.html (in English)
  */
 
-#if defined(__Linux__)
-#define _XOPEN_SOURCE 500
-#endif
-
-#include <gkrellm2/gkrellm.h>
 #include <unistd.h>
 #include <utime.h>
 #include <dirent.h>
+#include <gkrellm2/gkrellm.h>
 
 #include "interface.h"
 
-#define VERSION "2.0.4"
+#define VERSION "2.2.0-dev"
 
 #if defined(__FreeBSD__)
 #include "if_freebsd.c"
-#endif
-#if defined(__Linux__)
+#elif defined(__Linux__)
 #include "if_linux.c"
+#else
+#error The architectuire is not determined
 #endif
 
+#if GKRELLM_CHECK_VERSION(2,2,0)
+extern gint gkrellm_label_x_position();
+#else
 extern gint x_label_position();
+#endif
 
 #define GKRELLONGRUN "GKrelLongRun"
 #define KRELL_MAX 100
@@ -306,10 +307,17 @@ create_gkrellongrun_parts(GtkWidget *vbox, gint first,
 
 	textstyle = &decal->text_style;
 	if ( type != Slider )
+#if GKRELLM_CHECK_VERSION(2,2,0)
+		longrun.parts[type].decal->x_off = gkrellm_label_x_position(
+				panel->label->position, decal->w,
+				gdk_string_width( gdk_font_from_description(textstyle->font),
+					longrun.parts[type].label ), 0 );
+#else
 		longrun.parts[type].decal->x_off = x_label_position(
 				panel->label->position, decal->w,
 				gdk_string_width( textstyle->font,
 					longrun.parts[type].label ), 0 );
+#endif
 
 	if ( ! longrun.parts[type].enable ) {
 		gkrellm_monitor_height_adjust(-panel->h);
