@@ -173,6 +173,8 @@ set_longrun_frequency(GtkWidget *widget, gpointer data)
 			low = max_frequency;
 			high = max_frequency;
 			break;
+		default:
+			return;
 	}
 	low = ((low - min_frequency) * 100)/(max_frequency - min_frequency);
 	high = ((high - min_frequency) * 100)/(max_frequency - min_frequency);
